# About

![PyPI - Version](https://img.shields.io/pypi/v/hadal)

[![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch) [![linting - Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff) [![code style - Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

**hadal** ```/ˈheɪdəl/``` is a simple and efficient tool for mining and aligning sentences with pre-trained models.

# Implemented methods

| Level    | Method                                                   | Alignment type |
| -------- | -------------------------------------------------------- | -------------- |
| sentence | [margin-based](parallel_sentence_mining/margin_based.md) | `one-to-one`   |
